@@ -316,11 +316,16 @@ class NetworkBase:
         if not content_length == os.stat(filename)[6]:
             raise RuntimeError
 
-    def connect(self):
+    def connect(self, max_attempts=10):
         """
         Connect to WiFi using the settings found in secrets.py
+
+        :param max_attempts: The maximum number of of attempts to connect to WiFi before
+                             failing or use None to disable. Defaults to 10.
+
         """
         self._wifi.neo_status(STATUS_CONNECTING)
+        attempt = 1
         while not self._wifi.is_connected:
             # secrets dictionary must contain 'ssid' and 'password' at a minimum
             print("Connecting to AP", self._secrets["ssid"])
@@ -340,8 +345,13 @@ class NetworkBase:
                 self._wifi.connect(self._secrets["ssid"], self._secrets["password"])
                 self.requests = self._wifi.requests
             except RuntimeError as error:
+                if max_attempts is not None and attempt >= max_attempts:
+                    raise OSError(
+                        "Maximum number of attempts reached when trying to connect to WiFi"
+                    ) from error
                 print("Could not connect to internet", error)
                 print("Retrying in 3 seconds...")
+                attempt += 1
                 time.sleep(3)
             gc.collect()
 
@@ -362,11 +372,13 @@ class NetworkBase:
         self._io_client = IO_HTTP(aio_username, aio_key, self._wifi.requests)
         return self._io_client
 
-    def push_to_io(self, feed_key, data):
+    def push_to_io(self, feed_key, data, metadata=None, precision=None):
         """Push data to an adafruit.io feed
 
         :param str feed_key: Name of feed key to push data to.
         :param data: data to send to feed
+        :param dict metadata: Optional metadata associated with the data
+        :param int precision: Optional amount of precision points to send with floating point data
 
         """
 
@@ -385,7 +397,7 @@ class NetworkBase:
 
         while True:
             try:
-                io_client.send_data(feed_id["key"], data)
+                io_client.send_data(feed_id["key"], data, metadata, precision)
             except RuntimeError as exception:
                 print("An error occured, retrying! 2 -", exception)
                 continue
